==> sdx-2.2.1-src.zip: sdx-2.2.1/src/java/fr/gouv/culture/sdx/thesaurus/Concept.java <==
/*
SDX: Documentary System in XML.
Copyright (C) 2000, 2001, 2002  Ministere de la culture et de la communication (France), AJLSM

Ministere de la culture et de la communication,
Mission de la recherche et de la technologie
3 rue de Valois, 75042 Paris Cedex 01 (France)
mrt@culture.fr, michel.bottin@culture.fr

AJLSM, 17, rue Vital Carles, 33000 Bordeaux (France)
sevigny@ajlsm.com

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the
Free Software Foundation, Inc.
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
or connect to:
http://www.fsf.org/copyleft/gpl.html
*/
package fr.gouv.culture.sdx.thesaurus;

import fr.gouv.culture.sdx.document.IndexableDocument;

public interface Concept extends IndexableDocument {

    public final static String DOCTYPE_CONCEPT = "concept";

    /**Sets the term/value of the document
     *
     * @param value     The value
     */
    void setValue(String value);

    /**
     * Returns the document value (name, description, ...).
     */
    String getValue();

    /**Adds a relation to the document
     *
     * @param relationType   The relation type name or other key
     * @param relationValue The relation value or term
     */
    void addRelation(String relationType, String relationValue);

    /**
     * Returns a list of concepts related to this one.
     *
     * @param   type The relation type.
     */
    public String[] getRelations(int type);

    public void setXmlLang(String xmlLang);

    public String getXmlLang();


}

==> sdx-2.4-src.zip: sdx-2.4/src/java/fr/gouv/culture/sdx/thesaurus/Concept.java <==
/*
SDX: Documentary System in XML.
Copyright (C) 2000, 2001, 2002  Ministere de la culture et de la communication (France), AJLSM

Ministere de la culture et de la communication,
Mission de la recherche et de la technologie
3 rue de Valois, 75042 Paris Cedex 01 (France)
mrt@culture.fr, michel.bottin@culture.fr

AJLSM, 17, rue Vital Carles, 33000 Bordeaux (France)
sevigny@ajlsm.com

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the
Free Software Foundation, Inc.
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
or connect to:
http://www.fsf.org/copyleft/gpl.html
*/
package fr.gouv.culture.sdx.thesaurus;

import fr.gouv.culture.sdx.document.IndexableDocument;
import fr.gouv.culture.sdx.utils.constants.Node;

public interface Concept extends IndexableDocument {

    /**Identifier of the subclass document type*/
    String DOCTYPE_CONCEPT = "concept";

    String TERM = Node.Name.TERM;
    String ABBREVIATION_SCOPE_NOTE = "sn";
    String RELATION_NARROWER_TERM = "nt";
    String RELATION_BROADER_TERM = "bt";
    String RELATION_BROADER_TERMS = "bts";
    String RELATION_USED_FOR = "uf";
    String RELATION_EQUIVALENT_TERM = "et";
    String RELATION_RELATED_TERM = "rt";
    String RELATION_USE = "use";
    String RELATION_PARTIAL_EQIUVALENCE = "pe";

    String XMLLANG = "xmllang";

    /**Sets the term/value of the document
     *
     * @param value     The value
     */
    void setValue(String value);

    /**
     * Returns the document value (name, description, ...).
     */
    String getValue();

    /**Adds a relation to the document
     *
     * @param relationType   The relation type name or other key
     * @param relationValue The relation value or term
     */
    void addRelation(String relationType, String relationValue);

    /**
     * Returns a list of concept ids related to this one.
     *
     * @param   type The relation type.
     * @deprecated use getRelations(String type)
     */
    public String[] getRelations(int type);

    /**
     * Returns a list of concept ids related to this one.
     *
     * @param   type The relation type String.
     */
    public String[] getRelations(String type);

}
